crabnet.data.benchmark\_data.mp\_shear\_modulus package
=======================================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.mp_shear_modulus
   :members:
   :undoc-members:
   :show-inheritance:
